@@ -64,6 +64,7 @@
 #include <QtWidgets/QDockWidget>
 #include <QtGui/QFontDatabase>
 #include <QtGui/QImageReader>
+#include <QtGui/QScreen>
 #include <QtWidgets/QFileDialog>
 #include <QtWidgets/QLabel>
 #include <QtWidgets/QLayout>
@@ -80,6 +81,7 @@
 #include <QtHelp/QHelpEngineCore>
 #include <QtHelp/QHelpIndexModel>
 #include <QtHelp/QHelpSearchEngine>
+#include <QtHelp/QHelpFilterEngine>
 
 #include <cstdlib>
 
@@ -215,7 +217,7 @@ MainWindow::MainWindow(CmdLineParser *cmdLine, QWidget *parent)
         tabifyDockWidget(indexDock, bookmarkDock);
         tabifyDockWidget(bookmarkDock, searchDock);
         contentDock->raise();
-        const QRect screen = QApplication::desktop()->screenGeometry();
+        const QRect screen = QGuiApplication::primaryScreen()->geometry();
         resize(4*screen.width()/5, 4*screen.height()/5);
 
         adjustSize();   // make sure we won't start outside of the screen
@@ -268,8 +270,8 @@ MainWindow::MainWindow(CmdLineParser *cmdLine, QWidget *parent)
 
     if (!m_cmdLine->currentFilter().isEmpty()) {
         const QString &curFilter = m_cmdLine->currentFilter();
-        if (helpEngineWrapper.customFilters().contains(curFilter))
-            helpEngineWrapper.setCurrentFilter(curFilter);
+        if (helpEngineWrapper.filterEngine()->filters().contains(curFilter))
+            helpEngineWrapper.filterEngine()->setActiveFilter(curFilter);
     }
 
     if (usesDefaultCollection())
@@ -723,7 +725,7 @@ void MainWindow::setupFilterToolbar()
 
     m_filterCombo = new QComboBox(this);
     m_filterCombo->setMinimumWidth(QFontMetrics(QFont()).
-        width(QLatin1String("MakeTheComboBoxWidthEnough")));
+        horizontalAdvance(QLatin1String("MakeTheComboBoxWidthEnough")));
 
     QToolBar *filterToolBar = addToolBar(tr("Filter Toolbar"));
     filterToolBar->setObjectName(QLatin1String("FilterToolBar"));
@@ -737,9 +739,9 @@ void MainWindow::setupFilterToolbar()
 
     connect(&helpEngine, &HelpEngineWrapper::setupFinished,
             this, &MainWindow::setupFilterCombo, Qt::QueuedConnection);
-    connect(m_filterCombo, QOverload<const QString &>::of(&QComboBox::activated),
+    connect(m_filterCombo, QOverload<int>::of(&QComboBox::activated),
             this, &MainWindow::filterDocumentation);
-    connect(&helpEngine, &HelpEngineWrapper::currentFilterChanged,
+    connect(helpEngine.filterEngine(), &QHelpFilterEngine::filterActivated,
             this, &MainWindow::currentFilterChanged);
 
     setupFilterCombo();
@@ -840,7 +842,7 @@ void MainWindow::showPreferences()
             m_centralWidget, &CentralWidget::updateBrowserFont);
     connect(&dia, &PreferencesDialog::updateUserInterface,
             m_centralWidget, &CentralWidget::updateUserInterface);
-    dia.showDialog();
+    dia.exec();
 }
 
 void MainWindow::syncContents()
@@ -1048,21 +1050,27 @@ void MainWindow::setupFilterCombo()
 {
     TRACE_OBJ
     HelpEngineWrapper &helpEngine = HelpEngineWrapper::instance();
-    QString curFilter = m_filterCombo->currentText();
-    if (curFilter.isEmpty())
-        curFilter = helpEngine.currentFilter();
+    const QString currentFilter = helpEngine.filterEngine()->activeFilter();
     m_filterCombo->clear();
-    m_filterCombo->addItems(helpEngine.customFilters());
-    int idx = m_filterCombo->findText(curFilter);
+    m_filterCombo->addItem(tr("Unfiltered"));
+    const QStringList allFilters = helpEngine.filterEngine()->filters();
+    if (!allFilters.isEmpty())
+        m_filterCombo->insertSeparator(1);
+    for (const QString &filter : allFilters)
+        m_filterCombo->addItem(filter, filter);
+
+    int idx = m_filterCombo->findData(currentFilter);
     if (idx < 0)
         idx = 0;
     m_filterCombo->setCurrentIndex(idx);
 }
 
-void MainWindow::filterDocumentation(const QString &customFilter)
+void MainWindow::filterDocumentation(int filterIndex)
 {
     TRACE_OBJ
-    HelpEngineWrapper::instance().setCurrentFilter(customFilter);
+
+    const QString filter = m_filterCombo->itemData(filterIndex).toString();
+    HelpEngineWrapper::instance().filterEngine()->setActiveFilter(filter);
 }
 
 void MainWindow::expandTOC(int depth)
@@ -1091,7 +1099,7 @@ void MainWindow::indexingStarted()
         progressBar->setSizePolicy(sizePolicy);
 
         hlayout->setSpacing(6);
-        hlayout->setMargin(0);
+        hlayout->setContentsMargins(QMargins());
         hlayout->addWidget(progressBar);
 
         statusBar()->addPermanentWidget(m_progressWidget);
@@ -1143,8 +1151,9 @@ QString MainWindow::defaultHelpCollectionFileName()
 void MainWindow::currentFilterChanged(const QString &filter)
 {
     TRACE_OBJ
-    const int index = m_filterCombo->findText(filter);
-    Q_ASSERT(index != -1);
+    int index = m_filterCombo->findData(filter);
+    if (index < 0)
+        index = 0;
     m_filterCombo->setCurrentIndex(index);
 }
 
