@@ -102,12 +102,12 @@ namespace qdesigner_internal {
 FormWindowManager::FormWindowManager(QDesignerFormEditorInterface *core, QObject *parent) :
     QDesignerFormWindowManager(parent),
     m_core(core),
-    m_activeFormWindow(0),
+    m_activeFormWindow(nullptr),
     m_previewManager(new PreviewManager(PreviewManager::SingleFormNonModalPreview, this)),
     m_createLayoutContext(LayoutContainer),
-    m_morphLayoutContainer(0),
-    m_actionGroupPreviewInStyle(0),
-    m_actionShowFormWindowSettingsDialog(0)
+    m_morphLayoutContainer(nullptr),
+    m_actionGroupPreviewInStyle(nullptr),
+    m_actionShowFormWindowSettingsDialog(nullptr)
 {
     setupActions();
     qApp->installEventFilter(this);
@@ -145,7 +145,7 @@ bool FormWindowManager::eventFilter(QObject *o, QEvent *e)
 
     // If we don't have an active form, we only listen for WindowActivate to speed up integrations
     const QEvent::Type eventType = e->type();
-    if (m_activeFormWindow == 0 && eventType != QEvent::WindowActivate)
+    if (m_activeFormWindow == nullptr && eventType != QEvent::WindowActivate)
         return false;
 
     switch (eventType) { // Uninteresting events
@@ -198,7 +198,7 @@ bool FormWindowManager::eventFilter(QObject *o, QEvent *e)
     }
 
     FormWindow *fw = FormWindow::findFormWindow(widget);
-    if (fw == 0) {
+    if (fw == nullptr) {
         return false;
     }
 
@@ -294,7 +294,7 @@ void FormWindowManager::removeFormWindow(QDesignerFormWindowInterface *w)
     emit formWindowRemoved(formWindow);
 
     if (formWindow == m_activeFormWindow)
-        setActiveFormWindow(0);
+        setActiveFormWindow(nullptr);
 
     // Make sure that widget box is enabled by default
     if (m_formWindows.isEmpty() && m_core->widgetBox())
@@ -313,7 +313,7 @@ void FormWindowManager::setActiveFormWindow(QDesignerFormWindowInterface *w)
 
     m_activeFormWindow = formWindow;
 
-    QtResourceSet *resourceSet = 0;
+    QtResourceSet *resourceSet = nullptr;
     if (formWindow)
         resourceSet = formWindow->resourceSet();
     m_core->resourceModel()->setCurrentResourceSet(resourceSet);
@@ -332,7 +332,7 @@ void FormWindowManager::setActiveFormWindow(QDesignerFormWindowInterface *w)
         m_activeFormWindow->emitSelectionChanged();
         m_activeFormWindow->commandHistory()->setActive();
         // Trigger setActiveSubWindow on mdi area unless we are in toplevel mode
-        QMdiSubWindow *mdiSubWindow = 0;
+        QMdiSubWindow *mdiSubWindow = nullptr;
         if (QWidget *formwindow = m_activeFormWindow->parentWidget()) {
             mdiSubWindow = qobject_cast<QMdiSubWindow *>(formwindow->parentWidget());
         }
@@ -611,7 +611,7 @@ void FormWindowManager::slotActionBreakLayoutActivated()
 
 void FormWindowManager::slotActionSimplifyLayoutActivated()
 {
-    Q_ASSERT(m_activeFormWindow != 0);
+    Q_ASSERT(m_activeFormWindow != nullptr);
     QWidgetList selectedWidgets = m_activeFormWindow->selectedWidgets();
     m_activeFormWindow->simplifySelection(&selectedWidgets);
     if (selectedWidgets.size() != 1)
@@ -626,7 +626,7 @@ void FormWindowManager::slotActionSimplifyLayoutActivated()
 
 void FormWindowManager::slotActionAdjustSizeActivated()
 {
-    Q_ASSERT(m_activeFormWindow != 0);
+    Q_ASSERT(m_activeFormWindow != nullptr);
 
     m_activeFormWindow->beginCommand(tr("Adjust Size"));
 
@@ -634,7 +634,7 @@ void FormWindowManager::slotActionAdjustSizeActivated()
     m_activeFormWindow->simplifySelection(&selectedWidgets);
 
     if (selectedWidgets.isEmpty()) {
-        Q_ASSERT(m_activeFormWindow->mainContainer() != 0);
+        Q_ASSERT(m_activeFormWindow->mainContainer() != nullptr);
         selectedWidgets.append(m_activeFormWindow->mainContainer());
     }
 
@@ -688,7 +688,7 @@ QWidgetList FormWindowManager::layoutsToBeBroken(QWidget *w) const
 
     QWidget *parent = w->parentWidget();
     if (m_activeFormWindow->isMainContainer(w))
-        parent = 0;
+        parent = nullptr;
 
     QWidget *widget = core()->widgetFactory()->containerOfWidget(w);
 
@@ -806,7 +806,7 @@ static inline bool hasManagedLayoutItems(const QDesignerFormEditorInterface *cor
 void FormWindowManager::slotUpdateActions()
 {
     m_createLayoutContext = LayoutSelection;
-    m_morphLayoutContainer = 0;
+    m_morphLayoutContainer = nullptr;
     bool canMorphIntoVBoxLayout = false;
     bool canMorphIntoHBoxLayout = false;
     bool canMorphIntoGridLayout = false;
@@ -824,7 +824,7 @@ void FormWindowManager::slotUpdateActions()
     bool canChangeZOrder = true;
 
     do {
-        if (m_activeFormWindow == 0 || m_activeFormWindow->currentTool() != 0)
+        if (m_activeFormWindow == nullptr || m_activeFormWindow->currentTool() != 0)
             break;
 
         breakAvailable = hasLayoutsToBeBroken();
@@ -862,7 +862,7 @@ void FormWindowManager::slotUpdateActions()
         // Manipulate layout of a single widget
         m_createLayoutContext = LayoutSelection;
         QWidget *widget = core()->widgetFactory()->containerOfWidget(simplifiedSelection.first());
-        if (widget == 0) // We are looking at a page-based container with 0 pages
+        if (widget == nullptr) // We are looking at a page-based container with 0 pages
             break;
 
         const QDesignerWidgetDataBaseInterface *db = m_core->widgetDataBase();
@@ -878,7 +878,7 @@ void FormWindowManager::slotUpdateActions()
 
         layoutContainer = (item->isContainer() || m_activeFormWindow->isMainContainer(widget));
 
-        layoutAvailable = layoutContainer && m_activeFormWindow->hasInsertedChildren(widget) && managedLayout == 0;
+        layoutAvailable = layoutContainer && m_activeFormWindow->hasInsertedChildren(widget) && managedLayout == nullptr;
         simplifyAvailable = SimplifyLayoutCommand::canSimplify(m_core, widget);
         if (layoutAvailable) {
             m_createLayoutContext = LayoutContainer;
@@ -912,7 +912,7 @@ void FormWindowManager::slotUpdateActions()
     m_actionRaise->setEnabled(canChangeZOrder && selectedWidgetCount > 0);
 
 
-    m_actionSelectAll->setEnabled(m_activeFormWindow != 0);
+    m_actionSelectAll->setEnabled(m_activeFormWindow != nullptr);
 
     m_actionAdjustSize->setEnabled(unlaidoutWidgetCount > 0);
 
@@ -925,7 +925,7 @@ void FormWindowManager::slotUpdateActions()
 
     m_actionBreakLayout->setEnabled(breakAvailable);
     m_actionSimplifyLayout->setEnabled(simplifyAvailable);
-    m_actionShowFormWindowSettingsDialog->setEnabled(m_activeFormWindow != 0);
+    m_actionShowFormWindowSettingsDialog->setEnabled(m_activeFormWindow != nullptr);
 }
 
 QDesignerFormWindowInterface *FormWindowManager::createFormWindow(QWidget *parentWidget, Qt::WindowFlags flags)
@@ -972,12 +972,12 @@ void FormWindowManager::slotActionShowFormWindowSettingsDialog()
     if (!fw)
         return;
 
-    QDialog *settingsDialog = 0;
+    QDialog *settingsDialog = nullptr;
     const bool wasDirty = fw->isDirty();
 
     // Ask the language extension for a dialog. If not, create our own
     if (QDesignerLanguageExtension *lang = qt_extension<QDesignerLanguageExtension*>(m_core->extensionManager(), m_core))
-        settingsDialog = lang->createFormWindowSettingsDialog(fw, /*parent=*/ 0);
+        settingsDialog = lang->createFormWindowSettingsDialog(fw, /*parent=*/ nullptr);
 
     if (!settingsDialog)
         settingsDialog = new FormWindowSettings(fw);
@@ -1042,14 +1042,14 @@ QAction *FormWindowManager::action(Action action) const
         return m_actionShowFormWindowSettingsDialog;
     }
     qWarning("FormWindowManager::action: Unhanded enumeration value %d", action);
-    return 0;
+    return nullptr;
 }
 
 QActionGroup *FormWindowManager::actionGroup(ActionGroup actionGroup) const
 {
     switch (actionGroup) {
     case QDesignerFormWindowManagerInterface::StyledPreviewActionGroup:
-        if (m_actionGroupPreviewInStyle == 0) {
+        if (m_actionGroupPreviewInStyle == nullptr) {
             // Wish we could make the 'this' pointer mutable ;-)
             QObject *parent = const_cast<FormWindowManager*>(this);
             m_actionGroupPreviewInStyle = new PreviewActionGroup(m_core, parent);
@@ -1059,7 +1059,7 @@ QActionGroup *FormWindowManager::actionGroup(ActionGroup actionGroup) const
         return m_actionGroupPreviewInStyle;
     }
     qWarning("FormWindowManager::actionGroup: Unhanded enumeration value %d", actionGroup);
-    return 0;
+    return nullptr;
 }
 
 }
